@@ -324,7 +324,7 @@ class PTWorkstationsAssignment(WebhooksMixin, ChangeLoggedModel):
         ct_field='content_type',
         fk_field='object_id'
     )
-    app_system = models.ForeignKey(
+    pt_workstations = models.ForeignKey(
         to='ptuevents.PTWorkstations',
         on_delete=models.PROTECT,
         related_name='ptworkstations_assignments'
@@ -338,10 +338,10 @@ class PTWorkstationsAssignment(WebhooksMixin, ChangeLoggedModel):
                            'pt_workstations')
 
     def __str__(self):
-        return str(self.app_system)
+        return str(self.pt_workstations)
 
     def get_absolute_url(self):
-        return reverse('plugins:ptuevents:ptworkstations', args=[self.app_system.pk])
+        return reverse('plugins:ptuevents:ptworkstations', args=[self.pt_workstations.pk])
 
 
 @receiver(post_delete, sender=PTUsers, dispatch_uid='del_workstations_assignment')
