@@ -75,10 +75,10 @@ urlpatterns = (
 
     # PTWorkstations assignment
     path('ptworkstationsassignment/add/', views.PTWorkstationsAssignmentEditView.as_view(),
-         name='ptappsystemassignment_add'),
+         name='ptworkstationsassignment_add'),
     path('ptworkstationsassignment/<int:pk>/edit/', views.PTWorkstationsAssignmentEditView.as_view(),
-         name='ptappsystemassignment_edit'),
+         name='ptworkstationsassignment_edit'),
     path('ptworkstationsassignment/<int:pk>/delete/', views.PTWorkstationsAssignmentDeleteView.as_view(),
-         name='ptappsystemassignment_delete'),
+         name='ptworkstationsassignment_delete'),
 
 )
